@@ -1,9 +1,8 @@
-use super::NodeIdx;
 use crate::Node;
 use crate::TreePath;
 use std::fmt::Debug;
 
-/// Append a vector of child nodes to a parent node id.
+/// A patch where we add children to the target node
 #[derive(Clone, Debug, PartialEq)]
 pub struct AppendChildren<'a, NS, TAG, ATT, VAL>
 where
@@ -17,7 +16,7 @@ where
     /// index of the node we are going to append the children into
     pub patch_path: TreePath,
     /// children nodes to be appended and their corresponding new_node_idx
-    pub children: Vec<(NodeIdx, &'a Node<NS, TAG, ATT, VAL>)>,
+    pub children: Vec<(usize, &'a Node<NS, TAG, ATT, VAL>)>,
 }
 
 impl<'a, NS, TAG, ATT, VAL> AppendChildren<'a, NS, TAG, ATT, VAL>
@@ -31,7 +30,7 @@ where
     pub fn new(
         tag: &'a TAG,
         patch_path: TreePath,
-        children: Vec<(NodeIdx, &'a Node<NS, TAG, ATT, VAL>)>,
+        children: Vec<(usize, &'a Node<NS, TAG, ATT, VAL>)>,
     ) -> Self {
         AppendChildren {
             tag,
