@@ -1,7 +1,6 @@
 use mt_dom::{diff::*, patch::*, *};
 
-pub type MyNode =
-    Node<&'static str, &'static str, &'static str, &'static str, ()>;
+pub type MyNode = Node<&'static str, &'static str, &'static str, &'static str>;
 // should have no changes
 #[test]
 fn mixed_key_and_no_key_with_no_change() {
@@ -60,19 +59,13 @@ fn mixed_key_and_no_key_with_2_matched() {
         vec![
             ChangeText::new(
                 &Text::new("2"),
-                PatchPath::new(
-                    TreePath::start_at(4, vec![0, 1, 0]),
-                    TreePath::start_at(4, vec![0, 1, 0])
-                ),
+                TreePath::start_at(4, vec![0, 1, 0]),
                 &Text::new("1")
             )
             .into(),
             ChangeText::new(
                 &Text::new("2"),
-                PatchPath::new(
-                    TreePath::start_at(6, vec![0, 2, 0]),
-                    TreePath::start_at(6, vec![0, 2, 0])
-                ),
+                TreePath::start_at(6, vec![0, 2, 0]),
                 &Text::new("3")
             )
             .into()
@@ -112,18 +105,12 @@ fn mixed_key_and_no_key_with_misordered_2_matched() {
         vec![
             InsertNode::new(
                 Some(&"main"),
-                PatchPath::new(
-                    TreePath::start_at(1, vec![0, 0]),
-                    TreePath::start_at(1, vec![0, 0])
-                ),
+                TreePath::start_at(1, vec![0, 0]),
                 &element("div", vec![], vec![text(1)]),
             )
             .into(),
-            RemoveNode::new(
-                Some(&"div"),
-                PatchPath::old(TreePath::start_at(3, vec![0, 1]),),
-            )
-            .into(),
+            RemoveNode::new(Some(&"div"), TreePath::start_at(3, vec![0, 1]),)
+                .into(),
         ]
     );
 }
